Package: here
Title: A Simpler Way to Find Your Files
Version: 1.0.2
Date: 2025-09-06
Authors@R: 
    c(person(given = "Kirill",
             family = "M\u00fcller",
             role = c("aut", "cre"),
             email = "kirill@cynkra.com",
             comment = c(ORCID = "0000-0002-1416-3412")),
      person(given = "Jennifer",
             family = "Bryan",
             role = "ctb",
             email = "jenny@rstudio.com",
             comment = c(ORCID = "0000-0002-6983-2759")))
Description: Constructs paths to your project's files.
    Declare the relative path of a file within your project with 'i_am()'.
    Use the 'here()' function as a drop-in replacement for 'file.path()',
    it will always locate the files relative to your project root.
License: MIT + file LICENSE
URL: https://here.r-lib.org/, https://github.com/r-lib/here
BugReports: https://github.com/r-lib/here/issues
Imports: rprojroot (>= 2.1.0)
Suggests: conflicted, covr, fs, knitr, palmerpenguins, plyr, readr,
        rlang, rmarkdown, testthat, uuid, withr
VignetteBuilder: knitr
Encoding: UTF-8
RoxygenNote: 7.3.3.9000
Config/testthat/edition: 3
Config/Needs/website: tidyverse/tidytemplate
NeedsCompilation: no
Packaged: 2025-09-14 18:48:53 UTC; kirill
Author: Kirill Müller [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-1416-3412>),
  Jennifer Bryan [ctb] (ORCID: <https://orcid.org/0000-0002-6983-2759>)
Maintainer: Kirill Müller <kirill@cynkra.com>
Repository: CRAN
Date/Publication: 2025-09-15 05:10:09 UTC
Built: R 4.6.0; ; 2026-04-25 15:50:06 UTC; unix
