here

this module replaces a call to C< use here LIST; > with the contents of
C< LIST > at compile time.  perl then compiles C< LIST > and the remaining code.
there is not an implicit block around C< LIST >

an example is probably best:

    my $x;
    use here 'my $y';
    my $z;

is exactly equivalent to:

    my $x;
    my $y;
    my $z;

the important thing here is that C< $y > is still in scope, which would not be
the case with a runtime C< eval >:

    my $x;
    eval 'my $y';
    my $z; # $y is not in scope here!


INSTALLATION

To install this module, run the following commands:

	perl Build.PL
	./Build
	./Build test
	./Build install

SUPPORT AND DOCUMENTATION

After installing, you can find documentation for this module with the
perldoc command.

    perldoc here

You can also look for information at:

    RT, CPAN's request tracker
        http://rt.cpan.org/NoAuth/Bugs.html?Dist=here

    AnnoCPAN, Annotated CPAN documentation
        http://annocpan.org/dist/here

    CPAN Ratings
        http://cpanratings.perl.org/d/here

    Search CPAN
        http://search.cpan.org/dist/here/


LICENSE AND COPYRIGHT

Copyright (C) 2011 Eric Strom

This program is free software; you can redistribute it and/or modify it
under the terms of either: the GNU General Public License as published
by the Free Software Foundation; or the Artistic License.

See http://dev.perl.org/licenses/ for more information.
