---
title: "Palmer penguins"
author: "Kirill Müller"
date: "11/12/2020"
output: html_document
---

```{r setup, include=FALSE}
here::i_am("analysis/report.Rmd", uuid = "50208352-4ee9-4401-bb40-9f7ec81050da")
library(here)

knitr::opts_chunk$set(echo = TRUE)

penguins <- readr::read_csv(here("data/penguins.csv"))
```

## Linear model

```{r}
lm(flipper_length_mm ~ body_mass_g + species, penguins)
```
